@@ -23,6 +23,7 @@
 #
 
 import logging
+import re
 
 import numpy as np
 
@@ -239,6 +240,7 @@ class Instrument(object):
     @staticmethod
     def setting(set_command, docs,
                 validator=lambda x, y: x, values=(), map_values=False,
+                set_process=lambda v: v,
                 check_set_errors=False,
                 **kwargs):
         """Returns a property for the class based on the supplied
@@ -253,7 +255,9 @@ class Instrument(object):
                        as to map values if :code:`map_values` is True.
         :param map_values: A boolean flag that determines if the values should be 
                           interpreted as a map
-        :param check_set_errors: Toggles checking errors after setting     
+        :param set_process: A function that takes a value and allows processing
+                            before value mapping, returning the processed value
+        :param check_set_errors: Toggles checking errors after setting
         """
 
         if map_values and isinstance(values, dict):
@@ -264,7 +268,7 @@ class Instrument(object):
             raise LookupError("Instrument.setting properties can not be read.")
 
         def fset(self, value):
-            value = validator(value, values)
+            value = set_process(validator(value, values))
             if not map_values:
                 pass
             elif isinstance(values, (list, tuple, range)):
@@ -312,10 +316,44 @@ class FakeInstrument(Instrument):
     for testing purposes.
     """
 
-    def __init__(self, **kwargs):
+    def __init__(self, adapter=None, name=None, includeSCPI=False, **kwargs):
         super().__init__(
             FakeAdapter(),
-            "Fake Instrument",
-            includeSCPI=False,
+            name or "Fake Instrument",
+            includeSCPI=includeSCPI,
             **kwargs
         )
+
+    @staticmethod
+    def control(get_command, set_command, docs,
+                validator=lambda v, vs: v, values=(), map_values=False,
+                get_process=lambda v: v, set_process=lambda v: v,
+                check_set_errors=False, check_get_errors=False,
+                **kwargs):
+        """Fake Instrument.control.
+
+        Strip commands and only store and return values indicated by
+        format strings to mimic many simple commands.
+        This is analogous how the tests in test_instrument are handled.
+        """
+
+        # Regex search to find first format specifier in the command
+        fmt_spec_pattern = r'(%[\w.#-+ *]*[diouxXeEfFgGcrsa%])'
+        match = re.search(fmt_spec_pattern, set_command)
+        if match:
+            format_specifier = match.group(0)
+        else:
+            format_specifier = ''
+        # To preserve as much functionality as possible, call the real
+        # control method with modified get_command and set_command.
+        return Instrument.control(get_command="",
+                                  set_command=format_specifier,
+                                  docs=docs,
+                                  validator=validator,
+                                  values=values,
+                                  map_values=map_values,
+                                  get_process=get_process,
+                                  set_process=set_process,
+                                  check_set_errors=check_set_errors,
+                                  check_get_errors=check_get_errors,
+                                  **kwargs)
